chatter.migrations.0005_auto_20200925_1856 — django-chats 0.1.1 documentation

# Source code for chatter.migrations.0005_auto_20200925_1856

    # Generated by Django 3.1 on 2020-09-25 16:56

    from django.db import migrations

    class Migration(migrations.Migration):

        dependencies = [
            ('chatter', '0004_auto_20200925_1757'),
        ]

        operations = [
            migrations.AlterModelManagers(
                name='message',
                managers=[
                ],
            ),
        ]